@@ -16,7 +16,7 @@
 #'   Output is of class \code{lmlist}.
 #'
 #' @seealso \code{\link{fit2df}}
-#' @family \code{finalfit} model wrappers
+#' @family finalfit model wrappers
 #' @export
 #'
 #' @examples
@@ -34,7 +34,7 @@ lmmulti <- function(.data, dependent, explanatory, ...){
   result = list()
   for (i in 1:length(dependent)){
     result[[i]] = ff_eval(
-    	lm(paste(dependent[i], "~", paste(explanatory, collapse="+")), data = .data, ...)
+    	lm(ff_formula(dependent[i], explanatory), data = .data, ...)
     )
   }
   result = setNames(result, dependent)
